==> admost_flutter_plugin-1.1.0.tar.gz: lib/admost_interstitial.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

//import 'package:meta/meta.dart';
import 'admost_event_handler.dart';

class AdmostInterstitial extends AdmostEventHandler {
  static const MethodChannel _channel =
      const MethodChannel('admost_flutter/interstitial');

  int id;
  MethodChannel _adChannel;
  final String zoneId;
  final void Function(AdmostAdEvent, Map<String, dynamic>) listener;

  AdmostInterstitial({
    @required this.zoneId,
    this.listener,
  }) : super(listener) {
    if (zoneId == null) {
      print("zoneId cannot be null!");
    } else {
      id = hashCode;
      if (listener != null) {
        _adChannel = MethodChannel('admost_flutter/interstitial_$id');
        _adChannel.setMethodCallHandler(handleEvent);
      }
    }
  }

  Future<bool> get isLoaded async {
    final bool result =
        await _channel.invokeMethod('isLoaded', <String, dynamic>{
      'id': id,
    });
    return result;
  }

  void load() async {
    await _channel.invokeMethod('load', <String, dynamic>{
      'id': id,
      'zoneId': zoneId,
    });

    if (listener != null) {
      _channel.invokeMethod('setListener', <String, dynamic>{
        'id': id,
      });
    }
  }

  void show() async {
    if (await isLoaded == true) {
      _channel.invokeMethod('show', <String, dynamic>{
        'id': id,
      });
    }
  }

  void dispose() async {
    await _channel.invokeMethod('dispose', <String, dynamic>{
      'id': id,
    });
  }
}

==> admost_flutter_plugin-1.2.5.tar.gz: lib/admost_interstitial.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

//import 'package:meta/meta.dart';
import 'admost_event_handler.dart';

class AdmostInterstitial extends AdmostEventHandler {
  static const MethodChannel _channel =
      const MethodChannel('admost_flutter/interstitial');

  int? id;
  late MethodChannel _adChannel;
  final String zoneId;
  final void Function(AdmostAdEvent, Map<String, dynamic>)? listener;


  AdmostInterstitial({
    required this.zoneId,
    this.listener,
  }) : super(listener) {
    if (zoneId == null) {
      print("zoneId cannot be null!");
    } else {
      id = hashCode;
      if (listener != null) {
        _adChannel = MethodChannel('admost_flutter/interstitial_$id');
        _adChannel.setMethodCallHandler(handleEvent);
      }
    }
  }

  Future<bool?> get isLoaded async {
    final bool? result =
        await _channel.invokeMethod('isLoaded', <String, dynamic>{
      'id': id,
    });
    return result;
  }

  void load() async {
    await _channel.invokeMethod('load', <String, dynamic>{
      'id': id,
      'zoneId': zoneId,
    });

    if (listener != null) {
      _channel.invokeMethod('setListener', <String, dynamic>{
        'id': id,
      });
    }
  }

  void show([String? tag]) async {
    if (await isLoaded == true) {
      _channel.invokeMethod('show', <String, dynamic>{
        'id': id,
        'tag': tag
      });
    }
  }


  void dispose() async {
    await _channel.invokeMethod('dispose', <String, dynamic>{
      'id': id,
    });
  }
}
